==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Stories_Archive/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Yazdrlabilir Sayfa");
define("_FRIEND","Bu Haberi Arkadana Gnder");
define("_ARTICLES","Haber");
define("_USCORE","Puan");
define("_DATE","Tarih");
define("_JANUARY","Ocak");
define("_FEBRUARY","ubat");
define("_MARCH","Mart");
define("_APRIL","Nisan");
define("_MAY","Mays");
define("_JUNE","Haziran");
define("_JULY","Temmuz");
define("_AUGUST","Austos");
define("_SEPTEMBER","Eyll");
define("_OCTOBER","Ekim");
define("_NOVEMBER","Kasm");
define("_DECEMBER","Aralk");
define("_SELECTMONTH2VIEW","Ltfen grntlemek istediiniz ay sein:");
define("_SHOWALLSTORIES","TM Haberleri Gster");
define("_STORIESARCHIVE","Haber Arivi");
define("_ACTIONS","Hareketler");
define("_ARCHIVESINDEX","Haber Arivi ndeksi");
define("_ALLSTORIESARCH","Tm Haberler");
define("_NEXTPAGE","Sonraki Sayfa");
define("_PREVIOUSPAGE","nceki Sayfa");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Stories_Archive/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Yazdrlabilir Sayfa");
define("_FRIEND","Bu Haberi Arkadana Gnder");
define("_ARTICLES","Haber");
define("_USCORE","Puan");
define("_DATE","Tarih");

define("_SELECTMONTH2VIEW","Ltfen grntlemek istediiniz ay sein:");
define("_SHOWALLSTORIES","TM Haberleri Gster");
define("_STORIESARCHIVE","Haber Arivi");
define("_ACTIONS","Hareketler");
define("_ARCHIVESINDEX","Haber Arivi ndeksi");
define("_ALLSTORIESARCH","Tm Haberler");
define("_NEXTPAGE","Sonraki Sayfa");
define("_PREVIOUSPAGE","nceki Sayfa");

?>
